@@ -1,6 +1,6 @@
 # -*- coding:utf-8 -*-
 #
-# Copyright (C) 2019, Maximilian Köhl <mkoehl@cs.uni-saarland.de>
+# Copyright (C) 2019-2020, Maximilian Köhl <koehl@cs.unisaarland.de>
 
 """
 Momba is a Python library for *quantitative models*.
@@ -10,7 +10,11 @@ It's core modeling formalism are *stochastic hybrid automata* (SHA).
 
 from __future__ import annotations
 
-from . import ext, model
+from . import model
+
+from .metadata import version
+
+__version__ = version
 
 
-__all__ = ['ext', 'model']
+__all__ = ["model"]
